@@ -119,7 +119,7 @@ def attachSettings(settingsDict, enablePaypal=False):
     #=========================================================================
     # Django haystack connections.
     ADDING_HAYSTACK_CONNECTIONS = {
-        HAYSTACK_CONNECTIONS : {
+        'HAYSTACK_CONNECTIONS' : {
             'default': {
                 'ENGINE': 'haystack.backends.simple_backend.SimpleEngine',
             },
